@@ -5,7 +5,7 @@ use Moo;
 use DateTime;
 use Log::Any '$log';
 
-our $VERSION = '0.30'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 extends 'Finance::Bank::ID::Base';
 
@@ -402,17 +402,17 @@ sub _ps_get_transactions {
 
         if ($self->_variant eq 'perorangan' &&
             $tx->{date}->dow =~ /6|7/ &&
-            $tx->{description} !~ /^(BIAYA ADM|BUNGA|CR KOREKSI BUNGA|PAJAK BUNGA)$/) {
+            $tx->{description} !~ /^(BIAYA ADM|BUNGA|(CR|DR) KOREKSI BUNGA|PAJAK BUNGA)$/) {
             return "check failed in tx#$i: In KlikBCA Perorangan, all ".
                 "transactions must not be in Sat/Sun except for Interest and ".
-                "Admin Fee";
+                "Admin Fee: $tx->{description} ($tx->{date})";
             # note: in Tahapan perorangan, BIAYA ADM is set on
             # Fridays, but for Tapres (?) on last day of the month
         }
 
         if ($self->_variant eq 'bisnis' &&
             $tx->{date}->dow =~ /6|7/ &&
-            $tx->{description} !~ /^(BIAYA ADM|BUNGA|CR KOREKSI BUNGA|PAJAK BUNGA)$/) {
+            $tx->{description} !~ /^(BIAYA ADM|BUNGA|(CR|DR) KOREKSI BUNGA|PAJAK BUNGA)$/) {
             return "check failed in tx#$i: In KlikBCA Bisnis, all ".
                 "transactions must not be in Sat/Sun except for Interest and ".
                 "Admin Fee";
@@ -447,7 +447,7 @@ Finance::Bank::ID::BCA - Check your BCA accounts from Perl
 
 =head1 VERSION
 
-This document describes version 0.30 of Finance::Bank::ID::BCA (from Perl distribution Finance-Bank-ID-BCA), released on 2014-08-26.
+This document describes version 0.31 of Finance::Bank::ID::BCA (from Perl distribution Finance-Bank-ID-BCA), released on 2014-09-09.
 
 =head1 SYNOPSIS
 
@@ -730,7 +730,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Finance-Ba
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Finance-Bank-ID-BCA>.
+Source repository is at L<https://github.com/perlancar/perl-Finance-Bank-ID-BCA>.
 
 =head1 BUGS
 
@@ -742,11 +742,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
